#!/bin/sh
export PATH='/usr/lib/llvm15/bin/:/usr/lib/ccache/bin:/usr/bin'
printf '%s' 'name:                 http-media
version:              0.8.1.1
visibility:           public
id:                   http-media-0.8.1.1-AK9HPJI1u1FFBnYGC8cgRI
key:                  http-media-0.8.1.1-AK9HPJI1u1FFBnYGC8cgRI
license:              MIT
copyright:            (c) 2012-2023 Timothy Jones
maintainer:           Timothy Jones <tim@zmthy.net>
author:               Timothy Jones
homepage:             https://github.com/zmthy/http-media
synopsis:             Processing HTTP Content-Type and Accept headers
description:
    This library is intended to be a comprehensive solution to parsing and
    selecting quality-indexed values in HTTP headers.  It is capable of
    parsing both media types and language parameters from the Accept and
    Content header families, and can be extended to match against other
    accept headers as well.  Selecting the appropriate header value is
    achieved by comparing a list of server options against the
    quality-indexed values supplied by the client.

    In the following example, the Accept header is parsed and then matched
    against a list of server options to serve the appropriate media using
    '\''mapAcceptMedia'\'':

    > getHeader >>= maybe send406Error sendResourceWith . mapAcceptMedia
    >     [ ("text/html",        asHtml)
    >     , ("application/json", asJson)
    >     ]

    Similarly, the Content-Type header can be used to produce a parser for
    request bodies based on the given content type with '\''mapContentMedia'\'':

    > getContentType >>= maybe send415Error readRequestBodyWith . mapContentMedia
    >     [ ("application/json", parseJson)
    >     , ("text/plain",       parseText)
    >     ]

    The API is agnostic to your choice of server.

category:             Web
abi:                  6867bd5bdc60d24d70118a32430e278d
exposed:              True
exposed-modules:
    Network.HTTP.Media Network.HTTP.Media.Accept
    Network.HTTP.Media.Charset Network.HTTP.Media.Encoding
    Network.HTTP.Media.Language Network.HTTP.Media.MediaType
    Network.HTTP.Media.RenderHeader

hidden-modules:
    Network.HTTP.Media.Charset.Internal
    Network.HTTP.Media.Encoding.Internal
    Network.HTTP.Media.Language.Internal
    Network.HTTP.Media.MediaType.Internal Network.HTTP.Media.Quality
    Network.HTTP.Media.Utils

import-dirs:          /usr/lib/ghc-9.8.2/site-local/http-media-0.8.1.1
library-dirs:         /usr/lib/ghc-9.8.2/site-local/http-media-0.8.1.1
library-dirs-static:  /usr/lib/ghc-9.8.2/site-local/http-media-0.8.1.1
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-9.8.2
data-dir:             /usr/share/x86_64-linux-ghc-9.8.2/http-media-0.8.1.1
hs-libraries:         HShttp-media-0.8.1.1-AK9HPJI1u1FFBnYGC8cgRI
depends:
    base-4.19.1.0-inplace bytestring-0.12.1.0-inplace
    case-insensitive-1.2.1.0-Jg2zYF9HZMDGZeZxymEI8d
    containers-0.6.8-inplace utf8-string-1.0.2-3J0y0Vz60cv1Vw3n7HISJx

haddock-interfaces:
    /usr/share/doc/x86_64-linux-ghc-9.8.2/http-media-0.8.1.1/html/http-media.haddock

haddock-html:
    /usr/share/doc/x86_64-linux-ghc-9.8.2/http-media-0.8.1.1/html
' | '/usr/bin/ghc-pkg-9.8.2' 'update' '-' '--global' '--no-user-package-db' "$@"

